package javax.management;

import java.util.Set;
import java.util.Collections;
import java.util.Enumeration;
import java.security.Permission;
import java.security.PermissionCollection;

class MBeanServerPermissionCollection extends PermissionCollection
{
    private MBeanServerPermission collectionPermission;
    private static final long serialVersionUID = -5661980843569388590L;
    
    MBeanServerPermissionCollection() {
    }
    
    @Override
    public synchronized void add(Permission obj) {
        if (!(obj instanceof MBeanServerPermission)) {
            throw new IllegalArgumentException("Permission not an MBeanServerPermission: " + obj);
        }
        if (this.isReadOnly()) {
            throw new SecurityException("Read-only permission collection");
        }
        MBeanServerPermission collectionPermission = (MBeanServerPermission)obj;
        if (this.collectionPermission == null) {
            this.collectionPermission = collectionPermission;
        }
        else if (!this.collectionPermission.implies(obj)) {
            this.collectionPermission = new MBeanServerPermission(this.collectionPermission.mask | collectionPermission.mask);
        }
        return;
    }
    
    @Override
    public synchronized boolean implies(Permission permission) {
        return this.collectionPermission != null && this.collectionPermission.implies(permission);
    }
    
    @Override
    public synchronized Enumeration<Permission> elements() {
        Set c;
        if (this.collectionPermission == null) {
            c = Collections.emptySet();
        }
        else {
            c = Collections.singleton(this.collectionPermission);
        }
        return Collections.enumeration(c);
    }
}
